@@ -197,6 +197,73 @@ class DslTestCase(unittest.TestCase):
         except AssertionError:
             pass
 
+    def test_class_has_props(self):
+        d = type("CommentForm", (object,), {'text': 'textvalue', 'author': 'the_author'})
+
+        d | should.have_properties({
+            'text': 'textvalue',
+            'author': 'the_author',
+        })
+
+    def test_object_has_props(self):
+        Cls = type("CommentForm", (object,), {'text': '', 'author': ''})
+        d = Cls()
+        d.text = 'textvalue'
+        d.author = 'the_author'
+
+        d | should.have_properties({
+            'text': 'textvalue',
+            'author': 'the_author',
+        })
+
+    def test_object_has_dynamic_props(self):
+        Cls = type("CommentForm", (object,), {})
+        d = Cls()
+        d.added_text = 'textvalue'
+        d.added_author = 'the_author'
+
+        d | should.have_attrs({
+            'added_text': 'textvalue',
+            'added_author': should.be_a_string(),
+        })
+
+    def test_object_has_dynamic_props_with_kwargs(self):
+        Cls = type("CommentForm", (object,), {})
+        d = Cls()
+        d.added_text = 'textvalue'
+        d.added_author = 'the_author'
+
+        d | should.have_attrs(added_text='textvalue', added_author=should.be_a_string())
+
+    def test_object_has_dynamic_props_with_non_existing_kwargs(self):
+        Cls = type("CommentForm", (object,), {})
+        d = Cls()
+        d.added_text = 'textvalue'
+        d.added_author = 'the_author'
+        with self.assertRaises(AssertionError):
+            d | should.have_attrs(added_text='textvalue', added_author=should.be_a_string(), fake='foo')
+
+    def test_has_props_non_class(self):
+        d = "fail"
+
+        with self.assertRaises(AssertionError):
+            d | should.have_properties({
+                'text': should.be_a_string(),
+                'author': 'the_author',
+            })
+
+    def test_old_style_class_has_props(self):
+        class CommentForm:
+            text_field = "textvalue"
+            author_field = "the_author"
+
+        d = CommentForm()
+
+        d | should.have_properties({
+            'text_field': 'textvalue',
+            'author_field': 'the_author',
+        })
+
     def test_apply(self):
         import json
         d = '{"foo":"bar"}'
